package ovh.herisson.Clyde.Services;

import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;
import ovh.herisson.Clyde.Repositories.UserRepository;
import ovh.herisson.Clyde.Tables.Role;
import ovh.herisson.Clyde.Tables.User;

import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

@Service
public class UserService {

    private final UserRepository userRepo;
    private final BCryptPasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

    public UserService(UserRepository userRepo){
        this.userRepo = userRepo;
    }


    public User getUser(String identifier){
        if (identifier == null) return null;
        try {
            int id = Integer.parseInt(identifier);
            return userRepo.findById(id);
        }
        catch (NumberFormatException nfe){
            return userRepo.findByEmail(identifier);
        }
    }


    public boolean checkPassword(User user, String tryingPassword){
        return passwordEncoder.matches(tryingPassword,  user.getPassword());
    }

    /** Saves an example of :
     * an Admin with id 1, email : admin@admin.com and password: admin
     * a Student with id 2, email: student@student.com and password: student (no cursus yet)
     * a Secretary with id 3, email: secretary@secretary.com and password: secretary
     * a Teacher (same)
     * and they all have silly names (hihi)
     */
    public Iterable<User> postMockUsers(){
        User herobrine = new User("brine","hero","admin@admin.com","in your WalLs","ShadowsLand",new Date(0), Role.Admin,passwordEncoder.encode("admin"));
        User Joe = new User("Mama","Joe","student@student.com","roundabout","DaWarudo",new Date(0), Role.Student,passwordEncoder.encode("student"));
        User Meh = new User("Inspiration","lackOf","secretary@secretary.com","a Box","the street",new Date(0), Role.Teacher,passwordEncoder.encode("secretary"));
        User joke = new User("CthemBalls","Lemme","teacher@teacher.com","lab","faculty",new Date(0), Role.Teacher,passwordEncoder.encode("teacher"));

        userRepo.save(herobrine);
        userRepo.save(Joe);
        userRepo.save(Meh);
        userRepo.save(joke);

        return new ArrayList<User>(Arrays.asList(herobrine,Joe,Meh,joke));
    }

    public void save(User  user){
        userRepo.save(user);
    }

    public Iterable<User> getAll(){
        return userRepo.findAll();
    }

}